Module: Phred

Extended by:
Phred
Included in:
Phred, Record
Defined in:
lib/dna/phred.rb

Overview

Phred - intended to be used as a mixin to add phred-score conversions to integers with byte-offset taken into account and also for conversion from byte to probability.

en.wikipedia.org/wiki/FASTQ_format