Module: Phred
Overview
Phred - intended to be used as a mixin to add phred-score conversions to integers with byte-offset taken into account and also for conversion from byte to probability.
Phred - intended to be used as a mixin to add phred-score conversions to integers with byte-offset taken into account and also for conversion from byte to probability.