Class: QSEQ
Overview
QSEQ record
Instance Attribute Summary collapse
-
#filtered ⇒ Object
Returns the value of attribute filtered.
-
#index ⇒ Object
Returns the value of attribute index.
-
#lane ⇒ Object
Returns the value of attribute lane.
-
#machine ⇒ Object
Returns the value of attribute machine.
-
#quality ⇒ Object
Returns the value of attribute quality.
-
#read_no ⇒ Object
Returns the value of attribute read_no.
-
#run ⇒ Object
Returns the value of attribute run.
-
#sequence ⇒ Object
Returns the value of attribute sequence.
-
#tile ⇒ Object
Returns the value of attribute tile.
-
#x ⇒ Object
Returns the value of attribute x.
-
#y ⇒ Object
Returns the value of attribute y.
Instance Method Summary collapse
- #header ⇒ Object
-
#initialize(args = {}) ⇒ QSEQ
constructor
A new instance of QSEQ.
- #to_s ⇒ Object
Methods inherited from Record
Constructor Details
#initialize(args = {}) ⇒ QSEQ
Returns a new instance of QSEQ.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/dna/parsers/qseq.rb', line 35 def initialize(args={}) # These are the properties defined by the qseq spec # they must be in the same order that they appear in the tab-separated qseq file @properties = :machine, :run, :lane, :tile, :x, :y, :index, :read_no, :sequence, :quality, :filtered @machine = args[:machine] @run = args[:run] @lane = args[:lane] @tile = args[:tile] @x = args[:x] @y = args[:y] @index = args[:index] @read_no = args[:read_no] @sequence = args[:sequence] @quality = args[:quality] @filtered = args[:filtered] end |
Instance Attribute Details
#filtered ⇒ Object
Returns the value of attribute filtered.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def filtered @filtered end |
#index ⇒ Object
Returns the value of attribute index.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def index @index end |
#lane ⇒ Object
Returns the value of attribute lane.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def lane @lane end |
#machine ⇒ Object
Returns the value of attribute machine.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def machine @machine end |
#quality ⇒ Object
Returns the value of attribute quality.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def quality @quality end |
#read_no ⇒ Object
Returns the value of attribute read_no.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def read_no @read_no end |
#run ⇒ Object
Returns the value of attribute run.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def run @run end |
#sequence ⇒ Object
Returns the value of attribute sequence.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def sequence @sequence end |
#tile ⇒ Object
Returns the value of attribute tile.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def tile @tile end |
#x ⇒ Object
Returns the value of attribute x.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def x @x end |
#y ⇒ Object
Returns the value of attribute y.
33 34 35 |
# File 'lib/dna/parsers/qseq.rb', line 33 def y @y end |
Instance Method Details
#header ⇒ Object
56 57 58 |
# File 'lib/dna/parsers/qseq.rb', line 56 def header @properties.collect { |x| self.send(x) }.join("\t") end |
#to_s ⇒ Object
52 53 54 |
# File 'lib/dna/parsers/qseq.rb', line 52 def to_s @properties.collect { |x| self.send(x) }.join("\t") end |